@@ -1,5 +1,6 @@
 from django.db import models
 from django import forms
+from django.conf import settings
 from .widgets import ImageCropWidget
 
 
@@ -20,10 +21,12 @@ class ImageCropField(models.ImageField):
 
 
 class ImageRatioField(models.CharField):
-    def __init__(self, image_field, size, adapt_rotation=False, verbose_name=None):
+    def __init__(self, image_field, size, adapt_rotation=False, verbose_name=None,
+                 size_warning=getattr(settings, 'IMAGE_CROPPING_SIZE_WARNING', False)):
         self.width, self.height = size.split('x')
         self.image_field = image_field
         self.adapt_rotation = adapt_rotation
+        self.size_warning = size_warning
         super(ImageRatioField, self).__init__(max_length=255, blank=True, verbose_name=verbose_name)
 
     def formfield(self, *args, **kwargs):
@@ -33,6 +36,7 @@ class ImageRatioField(models.CharField):
             'data-image-field': self.image_field,
             'data-my-name': self.name,
             'data-adapt-rotation': str(self.adapt_rotation).lower(),
+            'data-size-warning': str(self.size_warning).lower(),
             'class': 'image-ratio',
         })
         return super(ImageRatioField, self).formfield(*args, **kwargs)
